@@ -26,7 +26,6 @@
 #include <gio/gio.h>
 
 #include "common.h"
-#include "compat.h"
 #include "backendgvfs.h"
 #include "bookmark.h"
 #include "settings.h"
@@ -36,9 +35,6 @@
 
 typedef struct _GigoloBrowseNetworkPanelPrivate			GigoloBrowseNetworkPanelPrivate;
 
-#define GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(obj)		(G_TYPE_INSTANCE_GET_PRIVATE((obj),\
-			GIGOLO_BROWSE_NETWORK_PANEL_TYPE, GigoloBrowseNetworkPanelPrivate))
-
 struct _GigoloBrowseNetworkPanelPrivate
 {
 	GigoloWindow *parent;
@@ -68,16 +64,16 @@ static void tree_selection_changed_cb(GtkTreeSelection *selection, GigoloBrowseN
 static void browse_network_finished_cb(G_GNUC_UNUSED GigoloBackendGVFS *bnd, GigoloBrowseNetworkPanel *panel);
 
 
-G_DEFINE_TYPE(GigoloBrowseNetworkPanel, gigolo_browse_network_panel, GTK_TYPE_VBOX);
+G_DEFINE_TYPE_WITH_PRIVATE(GigoloBrowseNetworkPanel, gigolo_browse_network_panel, GTK_TYPE_BOX);
 
 
 static void gigolo_browse_network_panel_finalize(GObject *object)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(object);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(GIGOLO_BROWSE_NETWORK_PANEL(object));
 	GigoloBackendGVFS *backend;
 
 	gtk_widget_destroy(priv->popup_menu);
-	gdk_cursor_unref(priv->wait_cursor);
+	g_object_unref(priv->wait_cursor);
 
 	backend = gigolo_window_get_backend(priv->parent);
 	if (backend != NULL && IS_GIGOLO_BACKEND_GVFS(backend) && priv->browse_network_signal_id > 0)
@@ -99,14 +95,13 @@ static void gigolo_browse_network_panel_class_init(GigoloBrowseNetworkPanelClass
 	g_object_class = G_OBJECT_CLASS(klass);
 	g_object_class->finalize = gigolo_browse_network_panel_finalize;
 
-	gigolo_browse_network_panel_parent_class = (GtkVBoxClass*) g_type_class_peek(GTK_TYPE_VBOX);
-	g_type_class_add_private(klass, sizeof(GigoloBrowseNetworkPanelPrivate));
+	gigolo_browse_network_panel_parent_class = (GtkBoxClass*) g_type_class_peek(GTK_TYPE_BOX);
 }
 
 
 static void mount_share(GigoloBrowseNetworkPanel *panel, GigoloBookmarkEditDialogMode mode)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(priv->tree));
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -209,19 +204,19 @@ static void find_empty_nodes(GtkTreeModel *model)
 
 static void browse_network_finished_cb(G_GNUC_UNUSED GigoloBackendGVFS *bnd, GigoloBrowseNetworkPanel *panel)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 
 	find_empty_nodes(GTK_TREE_MODEL(priv->store));
 
 	gtk_widget_set_sensitive(priv->button_refresh, TRUE);
 
-	gdk_window_set_cursor(gigolo_widget_get_window(GTK_WIDGET(panel)), NULL);
+	gdk_window_set_cursor(gtk_widget_get_window(GTK_WIDGET(panel)), NULL);
 }
 
 
 static void gigolo_browse_network_panel_refresh(GigoloBrowseNetworkPanel *panel)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 
 	gtk_widget_set_sensitive(priv->button_refresh, FALSE);
 	gtk_tree_store_clear(priv->store);
@@ -233,9 +228,9 @@ static void gigolo_browse_network_panel_refresh(GigoloBrowseNetworkPanel *panel)
 
 static gboolean delay_refresh(GigoloBrowseNetworkPanel *panel)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 
-	gdk_window_set_cursor(gigolo_widget_get_window(GTK_WIDGET(panel)), priv->wait_cursor);
+	gdk_window_set_cursor(gtk_widget_get_window(GTK_WIDGET(panel)), priv->wait_cursor);
 	/* Force the update of the cursor */
 	while (g_main_context_iteration(NULL, FALSE));
 
@@ -252,7 +247,7 @@ static void button_refresh_click_cb(G_GNUC_UNUSED GtkToolButton *btn, GigoloBrow
 
 static void button_close_click_cb(G_GNUC_UNUSED GtkToolButton *btn, GigoloBrowseNetworkPanel *panel)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 	GigoloSettings *settings = gigolo_window_get_settings(GIGOLO_WINDOW(priv->parent));
 	/* hide the panel by setting the property to FALSE */
 	g_object_set(settings, "show-panel", FALSE, NULL);
@@ -262,10 +257,10 @@ static void button_close_click_cb(G_GNUC_UNUSED GtkToolButton *btn, GigoloBrowse
 static gboolean tree_key_press_event(G_GNUC_UNUSED GtkWidget *widget, GdkEventKey *event,
 									 GigoloBrowseNetworkPanel *panel)
 {
-	if (event->keyval == GDK_Return ||
-		event->keyval == GDK_ISO_Enter ||
-		event->keyval == GDK_KP_Enter ||
-		event->keyval == GDK_space)
+	if (event->keyval == GDK_KEY_Return ||
+		event->keyval == GDK_KEY_ISO_Enter ||
+		event->keyval == GDK_KEY_KP_Enter ||
+		event->keyval == GDK_KEY_space)
 	{
 		mount_share(panel, GIGOLO_BE_MODE_CONNECT);
 		return TRUE;
@@ -279,9 +274,9 @@ static gboolean tree_button_release_event(G_GNUC_UNUSED GtkWidget *widget, GdkEv
 {
 	if (event->button == 3)
 	{
-		GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
-		gtk_menu_popup(GTK_MENU(priv->popup_menu), NULL, NULL, NULL, NULL,
-															event->button, event->time);
+		GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
+		gtk_menu_popup_at_pointer (GTK_MENU(priv->popup_menu),
+								   (GdkEvent *)event);
 		return TRUE;
 	}
 	return FALSE;
@@ -349,7 +344,7 @@ static void tree_popup_activate_cb(GtkCheckMenuItem *item, gpointer user_data)
 
 static void tree_selection_changed_cb(GtkTreeSelection *selection, GigoloBrowseNetworkPanel *panel)
 {
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean set = FALSE;
@@ -402,7 +397,7 @@ static void tree_prepare(GigoloBrowseNetworkPanel *panel)
 	GtkTreeSelection *selection;
 	GtkWidget *tree, *menu, *item;
 	GtkTreeStore *store;
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 
 	tree = gtk_tree_view_new();
 	store = gtk_tree_store_new(GIGOLO_BROWSE_NETWORK_N_COLUMNS,
@@ -410,14 +405,11 @@ static void tree_prepare(GigoloBrowseNetworkPanel *panel)
 
     column = gtk_tree_view_column_new();
 
-	if (gtk_check_version(2, 14, 0) == NULL)
-	{
-		icon_renderer = gtk_cell_renderer_pixbuf_new();
-		gtk_tree_view_column_pack_start(column, icon_renderer, FALSE);
-		gtk_tree_view_column_set_attributes(column, icon_renderer,
-			"gicon", GIGOLO_BROWSE_NETWORK_COL_ICON, NULL);
-		g_object_set(icon_renderer, "xalign", 0.0, NULL);
-	}
+	icon_renderer = gtk_cell_renderer_pixbuf_new();
+	gtk_tree_view_column_pack_start(column, icon_renderer, FALSE);
+	gtk_tree_view_column_set_attributes(column, icon_renderer,
+		"gicon", GIGOLO_BROWSE_NETWORK_COL_ICON, NULL);
+	g_object_set(icon_renderer, "xalign", 0.0, NULL);
 
 	text_renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_set_enable_search(GTK_TREE_VIEW(tree), FALSE);
@@ -443,17 +435,14 @@ static void tree_prepare(GigoloBrowseNetworkPanel *panel)
 	/* popup menu */
 	menu = gtk_menu_new();
 
-	priv->item_connect = item = gtk_image_menu_item_new_from_stock(GTK_STOCK_CONNECT, NULL);
+	priv->item_connect = item = gtk_menu_item_new_with_mnemonic(_("_Connect"));
 	g_object_set_data(G_OBJECT(item), "panel", panel);
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
 	g_signal_connect(item, "activate", G_CALLBACK(tree_popup_activate_cb),
 		GINT_TO_POINTER(ACTION_CONNECT));
 
-	priv->item_bookmark = item = gtk_image_menu_item_new_with_mnemonic(_("Create _Bookmark"));
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item),
-		gtk_image_new_from_icon_name(
-			gigolo_find_icon_name("bookmark-new", GTK_STOCK_EDIT), GTK_ICON_SIZE_BUTTON));
+	priv->item_bookmark = item = gtk_menu_item_new_with_mnemonic(_("Create _Bookmark"));
 	g_object_set_data(G_OBJECT(item), "panel", panel);
 	gtk_widget_show(item);
 	gtk_container_add(GTK_CONTAINER(menu), item);
@@ -478,22 +467,24 @@ static void gigolo_browse_network_panel_init(GigoloBrowseNetworkPanel *panel)
 {
 	GtkWidget *swin, *toolbar;
 	GtkToolItem *toolitem;
-	GigoloBrowseNetworkPanelPrivate *priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(panel);
+	GigoloBrowseNetworkPanelPrivate *priv = gigolo_browse_network_panel_get_instance_private(panel);
 
 	priv->browse_network_signal_id = 0;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (panel), GTK_ORIENTATION_VERTICAL);
 	toolbar = gtk_toolbar_new();
 	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_BOTH_HORIZ);
 	gtk_toolbar_set_icon_size(GTK_TOOLBAR(toolbar), GTK_ICON_SIZE_BUTTON);
 
-	toolitem = gtk_tool_button_new_from_stock(GTK_STOCK_CONNECT);
+	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("gtk-connect",
+		gtk_toolbar_get_icon_size(GTK_TOOLBAR(toolbar))), NULL);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Connect to the selected share"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 	g_signal_connect(toolitem, "clicked", G_CALLBACK(button_connect_click_cb), panel);
 	priv->button_connect = GTK_WIDGET(toolitem);
 
 	toolitem = gtk_tool_button_new(
-		gtk_image_new_from_icon_name(gigolo_find_icon_name("bookmark-new", GTK_STOCK_EDIT), GTK_ICON_SIZE_BUTTON),
+		gtk_image_new_from_icon_name(gigolo_find_icon_name("bookmark-new", "gtk-edit"), GTK_ICON_SIZE_BUTTON),
 		_("Create _Bookmark"));
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Create a bookmark from the selected share"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
@@ -503,7 +494,8 @@ static void gigolo_browse_network_panel_init(GigoloBrowseNetworkPanel *panel)
 	toolitem = gtk_separator_tool_item_new();
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 
-	toolitem = gtk_tool_button_new_from_stock(GTK_STOCK_REFRESH);
+	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("gtk-refresh",
+		gtk_toolbar_get_icon_size(GTK_TOOLBAR(toolbar))), NULL);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Refresh the network list"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 	g_signal_connect(toolitem, "clicked", G_CALLBACK(button_refresh_click_cb), panel);
@@ -514,7 +506,8 @@ static void gigolo_browse_network_panel_init(GigoloBrowseNetworkPanel *panel)
 	gtk_tool_item_set_expand(toolitem, TRUE);
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 
-	toolitem = gtk_tool_button_new_from_stock(GTK_STOCK_CLOSE);
+	toolitem = gtk_tool_button_new(gtk_image_new_from_icon_name ("gtk-close",
+		gtk_toolbar_get_icon_size(GTK_TOOLBAR(toolbar))), NULL);
 	gtk_widget_set_tooltip_text(GTK_WIDGET(toolitem), _("Close panel"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), toolitem, -1);
 	g_signal_connect(toolitem, "clicked", G_CALLBACK(button_close_click_cb), panel);
@@ -533,7 +526,7 @@ static void gigolo_browse_network_panel_init(GigoloBrowseNetworkPanel *panel)
 	gtk_widget_show_all(toolbar);
 	gtk_widget_show_all(swin);
 
-	priv->wait_cursor = gdk_cursor_new(GDK_WATCH);
+	priv->wait_cursor = gdk_cursor_new_for_display(gdk_display_get_default(), GDK_WATCH);
 
 	g_signal_connect_after(panel, "realize", G_CALLBACK(realize_cb), NULL);
 }
@@ -547,7 +540,7 @@ GtkWidget *gigolo_browse_network_panel_new(GigoloWindow *parent)
 
 	self = g_object_new(GIGOLO_BROWSE_NETWORK_PANEL_TYPE, NULL);
 
-	priv = GIGOLO_BROWSE_NETWORK_PANEL_GET_PRIVATE(self);
+	priv = gigolo_browse_network_panel_get_instance_private(GIGOLO_BROWSE_NETWORK_PANEL(self));
 	priv->parent = parent;
 
 	backend = gigolo_window_get_backend(parent);
